//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[HanHuOptions](index.md)/[HanHuOptions](-han-hu-options.md)

# HanHuOptions

[common]\
constructor(aotenjou: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false, hasKiriageMangan: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false, hasKazoeYakuman: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = true)
